-
+
diff --git a/cave/com.raytheon.uf.viz.derivparam/src/com/raytheon/uf/viz/derivparam/library/DerivedParameterGenerator.java b/cave/com.raytheon.uf.viz.derivparam/src/com/raytheon/uf/viz/derivparam/library/DerivedParameterGenerator.java
index 166520afe3..d3eeb86dc8 100644
--- a/cave/com.raytheon.uf.viz.derivparam/src/com/raytheon/uf/viz/derivparam/library/DerivedParameterGenerator.java
+++ b/cave/com.raytheon.uf.viz.derivparam/src/com/raytheon/uf/viz/derivparam/library/DerivedParameterGenerator.java
@@ -76,15 +76,17 @@ import com.raytheon.uf.viz.derivparam.library.DerivParamMethod.MethodType;
*
*
* SOFTWARE HISTORY
- * Date Ticket# Engineer Description
- * ------------ ---------- ----------- --------------------------
- * Jul 03, 2008 brockwoo Initial creation
- * Nov 16, 2009 3120 rjpeter Removed use of LevelNameMappingFile.
- * Nov 20, 2009 3387 jelkins Use derived script's variableId instead
- * of filename
- * Nov 21, 2009 3576 rjpeter Refactored DerivParamDesc.
- * Jun 04, 2013 2041 bsteffen Switch derived parameters to use
- * concurrent python for threading.
+ * Date Ticket# Engineer Description
+ * ------------- -------- ----------- --------------------------
+ * Jul 03, 2008 brockwoo Initial creation
+ * Nov 16, 2009 3120 rjpeter Removed use of LevelNameMappingFile.
+ * Nov 20, 2009 3387 jelkins Use derived script's variableId instead
+ * of filename
+ * Nov 21, 2009 3576 rjpeter Refactored DerivParamDesc.
+ * Jun 04, 2013 2041 bsteffen Switch derived parameters to use
+ * concurrent python for threading.
+ * Mar 27, 2014 2945 bsteffen Recursively find definitions in
+ * subdirectories.
*
*
* @author brockwoo
@@ -236,7 +238,7 @@ public class DerivedParameterGenerator implements ILocalizationFileObserver {
LocalizationContext[] contexts = pm
.getLocalSearchHierarchy(LocalizationType.CAVE_STATIC);
LocalizationFile[] xmlFiles = pm.listFiles(contexts, XML_DIR,
- new String[] { ".xml" }, false, true);
+ new String[] { ".xml" }, true, true);
JAXBManager jaxbMan;
try {
jaxbMan = new JAXBManager(DerivParamDesc.class);
diff --git a/cave/com.raytheon.viz.grid/localization/styleRules/gridImageryStyleRules.xml b/cave/com.raytheon.viz.grid/localization/styleRules/gridImageryStyleRules.xml
index 38ebe8914b..e88a544816 100644
--- a/cave/com.raytheon.viz.grid/localization/styleRules/gridImageryStyleRules.xml
+++ b/cave/com.raytheon.viz.grid/localization/styleRules/gridImageryStyleRules.xml
@@ -4165,67 +4165,112 @@
-
- TPCSG
- TPCSG-20
- TPCSG-30
- TPCSG-40
- TPCSG-50
- TPCSG-60
- TPCSG-70
- TPCSG-80
- TPCSG-90
+ TPCSurgeProb
+ Surge10pctCumul_wTide
+ Surge20pctCumul_wTide
+ Surge30pctCumul_wTide
+ Surge40pctCumul_wTide
+ Surge50pctCumul_wTide
+ Surge10pctIncr_PHISH
+ Surge20pctIncr_PHISH
+ Surge30pctIncr_PHISH
+ Surge40pctIncr_PHISH
+ Surge50pctIncr_PHISH
+ Surge10pctCumul_PHISH
+ Surge20pctCumul_PHISH
+ Surge30pctCumul_PHISH
+ Surge40pctCumul_PHISH
+ Surge50pctCumul_PHISH
ft
+ NoPlane
- 0
+ -5
35
Grid/gridded data
- 3 5 7 9 11 13 15 17 19 21 23 25 27 29 31 33 35
+ -5 -3 0 3 5 7 9 11 13 15 17 19 21 23 25 27 29 31 33 35
+
-
- TPCSG-61E2
- TPCSG-91E2
- TPCSG-122E2
- TPCSG-152E2
- TPCSG-183E2
- TPCSG-213E2
- TPCSG-244E2
- TPCSG-274E2
- TPCSG-305E2
- TPCSG-335E2
- TPCSG-366E2
- TPCSG-396E2
- TPCSG-457E2
- TPCSG-427E2
- TPCSG-488E2
- TPCSG-518E2
- TPCSG-549E2
- TPCSG-579E2
- TPCSG-610E2
- TPCSG-640E2
- TPCSG-671E2
- TPCSG-701E2
- TPCSG-732E2
- TPCSG-762E2
+ TPCSurgeProb
+ PSurge2ftCumul_wTide
+ PSurge3ftCumul_wTide
+ PSurge4ftCumul_wTide
+ PSurge5ftCumul_wTide
+ PSurge6ftCumul_wTide
+ PSurge7ftCumul_wTide
+ PSurge8ftCumul_wTide
+ PSurge9ftCumul_wTide
+ PSurge10ftCumul_wTide
+ PSurge11ftCumul_wTide
+ PSurge12ftCumul_wTide
+ PSurge13ftCumul_wTide
+ PSurge14ftCumul_wTide
+ PSurge15ftCumul_wTide
+ PSurge16ftCumul_wTide
+ PSurge17ftCumul_wTide
+ PSurge18ftCumul_wTide
+ PSurge19ftCumul_wTide
+ PSurge20ftCumul_wTide
+ PSurge21ftCumul_wTide
+ PSurge22ftCumul_wTide
+ PSurge23ftCumul_wTide
+ PSurge24ftCumul_wTide
+ PSurge25ftCumul_wTide
+ PSurge0ftIncr_PHISH
+ PSurge1ftIncr_PHISH
+ PSurge2ftIncr_PHISH
+ PSurge3ftIncr_PHISH
+ PSurge4ftIncr_PHISH
+ PSurge5ftIncr_PHISH
+ PSurge6ftIncr_PHISH
+ PSurge7ftIncr_PHISH
+ PSurge8ftIncr_PHISH
+ PSurge9ftIncr_PHISH
+ PSurge10ftIncr_PHISH
+ PSurge11ftIncr_PHISH
+ PSurge12ftIncr_PHISH
+ PSurge13ftIncr_PHISH
+ PSurge14ftIncr_PHISH
+ PSurge15ftIncr_PHISH
+ PSurge16ftIncr_PHISH
+ PSurge17ftIncr_PHISH
+ PSurge18ftIncr_PHISH
+ PSurge19ftIncr_PHISH
+ PSurge20ftIncr_PHISH
+ PSurge0ftCumul_PHISH
+ PSurge1ftCumul_PHISH
+ PSurge2ftCumul_PHISH
+ PSurge3ftCumul_PHISH
+ PSurge4ftCumul_PHISH
+ PSurge5ftCumul_PHISH
+ PSurge6ftCumul_PHISH
+ PSurge7ftCumul_PHISH
+ PSurge8ftCumul_PHISH
+ PSurge9ftCumul_PHISH
+ PSurge10ftCumul_PHISH
+ PSurge11ftCumul_PHISH
+ PSurge12ftCumul_PHISH
+ PSurge13ftCumul_PHISH
+ PSurge14ftCumul_PHISH
+ PSurge15ftCumul_PHISH
+ PSurge16ftCumul_PHISH
+ PSurge17ftCumul_PHISH
+ PSurge18ftCumul_PHISH
+ PSurge19ftCumul_PHISH
+ PSurge20ftCumul_PHISH
%
+ NoPlane
0
100
diff --git a/cave/com.raytheon.viz.grid/localization/volumebrowser/FieldDisplayTypes.xml b/cave/com.raytheon.viz.grid/localization/volumebrowser/FieldDisplayTypes.xml
index 997811c16d..1554b75924 100644
--- a/cave/com.raytheon.viz.grid/localization/volumebrowser/FieldDisplayTypes.xml
+++ b/cave/com.raytheon.viz.grid/localization/volumebrowser/FieldDisplayTypes.xml
@@ -46,39 +46,6 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
@@ -114,4 +81,85 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/cave/com.raytheon.viz.volumebrowser/localization/menus/xml/fieldsMenus.xml b/cave/com.raytheon.viz.volumebrowser/localization/menus/xml/fieldsMenus.xml
index 6446a43fcf..ad6a1c0d0c 100644
--- a/cave/com.raytheon.viz.volumebrowser/localization/menus/xml/fieldsMenus.xml
+++ b/cave/com.raytheon.viz.volumebrowser/localization/menus/xml/fieldsMenus.xml
@@ -626,86 +626,177 @@
key="MnT6hr" indentText="false" />
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
av
@@ -309,40 +310,6 @@
tpsprd6
tp_ACR
tp_ALR
- PSurge4Ft
- PSurge5Ft
- PSurge6Ft
- Surge20Pct
- PSurge7Ft
- PSurge8Ft
- PSurge9Ft
- PSurge10Ft
- Surge30Pct
- PSurge11Ft
- PSurge12Ft
- PSurge13Ft
- Surge40Pct
- PSurge14Ft
- PSurge15Ft
- PSurge16Ft
- Surge50Pct
- PSurge17Ft
- PSurge18Ft
- PSurge19Ft
- Surge60Pct
- PSurge20Ft
- PSurge2Ft
- PSurge21Ft
- PSurge22Ft
- PSurge23Ft
- Surge70Pct
- PSurge24Ft
- PSurge25Ft
- Surge80Pct
- Surge90Pct
- PSurge3Ft
- SloshSurge
- Surge10Pct
tp_ecmwf
tp_FWR
tp_KRF
@@ -388,4 +355,61 @@
wssprd
wx
zagl
+ Surge10Pct
+ Surge20Pct
+ Surge30Pct
+ Surge40Pct
+ Surge50Pct
+ PSurge0Ft
+ PSurge1Ft
+ PSurge2Ft
+ PSurge3Ft
+ PSurge4Ft
+ PSurge5Ft
+ PSurge6Ft
+ PSurge7Ft
+ PSurge8Ft
+ PSurge9Ft
+ PSurge10Ft
+ PSurge11Ft
+ PSurge12Ft
+ PSurge13Ft
+ PSurge14Ft
+ PSurge15Ft
+ PSurge16Ft
+ PSurge17Ft
+ PSurge18Ft
+ PSurge19Ft
+ PSurge20Ft
+ PSurge21Ft
+ PSurge22Ft
+ PSurge23Ft
+ PSurge24Ft
+ PSurge25Ft
+ Surge10Pctincr
+ Surge20Pctincr
+ Surge30Pctincr
+ Surge40Pctincr
+ Surge50Pctincr
+ PSurge0Ftincr
+ PSurge1Ftincr
+ PSurge2Ftincr
+ PSurge3Ftincr
+ PSurge4Ftincr
+ PSurge5Ftincr
+ PSurge6Ftincr
+ PSurge7Ftincr
+ PSurge8Ftincr
+ PSurge9Ftincr
+ PSurge10Ftincr
+ PSurge11Ftincr
+ PSurge12Ftincr
+ PSurge13Ftincr
+ PSurge14Ftincr
+ PSurge15Ftincr
+ PSurge16Ftincr
+ PSurge17Ftincr
+ PSurge18Ftincr
+ PSurge19Ftincr
+ PSurge20Ftincr
diff --git a/edexOsgi/com.raytheon.edex.plugin.gfe/utility/edex_static/base/grid/gfeLevelMappingFile.xml b/edexOsgi/com.raytheon.edex.plugin.gfe/utility/edex_static/base/grid/gfeLevelMappingFile.xml
index 6a6ab2ab3d..b416a6a713 100644
--- a/edexOsgi/com.raytheon.edex.plugin.gfe/utility/edex_static/base/grid/gfeLevelMappingFile.xml
+++ b/edexOsgi/com.raytheon.edex.plugin.gfe/utility/edex_static/base/grid/gfeLevelMappingFile.xml
@@ -1,4 +1,7 @@
+
@@ -237,6 +240,9 @@
+
+
+
diff --git a/edexOsgi/com.raytheon.edex.plugin.gfe/utility/edex_static/base/grid/parameterInfo/TPCSurgeProb.xml b/edexOsgi/com.raytheon.edex.plugin.gfe/utility/edex_static/base/grid/parameterInfo/TPCSurgeProb.xml
index 701c191069..05076bddc0 100644
--- a/edexOsgi/com.raytheon.edex.plugin.gfe/utility/edex_static/base/grid/parameterInfo/TPCSurgeProb.xml
+++ b/edexOsgi/com.raytheon.edex.plugin.gfe/utility/edex_static/base/grid/parameterInfo/TPCSurgeProb.xml
@@ -1,12 +1,13 @@
+
21600
43200
64800
- 75600
86400
- 97200
108000
129600
151200
@@ -14,72 +15,95 @@
194400
216000
237600
+ 259200
+ 280800
288000
- 432000
+
- PSurge23Ft
- 80 hr Prob of Hurricane Storm Surge > 23 feet
- %
- percent
- ProbSurge23c
- 0.0
+ Surge10Pct
+ Hurricane Storm Surge Percentile(10)
+ m
+ meters
+ SURGE10pct
+ -100.0
100.0
-9999.0
0
- SFC
+ SFC 0 FHAG
+ FHAG0
SFC
- Surge60Pct
- 80 hr Hurricane Storm Surge Percentile(60)
- feet
- feet
- SURGE60pct
- 0.0
- 25.0
+ Surge20Pct
+ Hurricane Storm Surge Percentile(20)
+ m
+ meters
+ SURGE20pct
+ -100.0
+ 100.0
-9999.0
0
- SFC
+ SFC 0 FHAG
+ FHAG0
+ SFC
+
+
+
+ Surge30Pct
+ Hurricane Storm Surge Percentile(30)
+ m
+ meters
+ SURGE30pct
+ -100.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
SFC
Surge40Pct
- 80 hr Hurricane Storm Surge Percentile(40)
- feet
- feet
+ Hurricane Storm Surge Percentile(40)
+ m
+ meters
SURGE40pct
- 0.0
- 25.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge21Ft
- 80 hr Prob of Hurricane Storm Surge > 21 feet
- %
- percent
- ProbSurge21c
- 0.0
+ -100.0
100.0
-9999.0
0
- SFC
+ SFC 0 FHAG
+ FHAG0
SFC
+
+ Surge50Pct
+ Hurricane Storm Surge Percentile(50)
+ m
+ meters
+ SURGE50pct
+ -100.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
PSurge25Ft
- 80 hr Prob of Hurricane Storm Surge > 25 feet
+ Prob of Hurricane Storm Surge > 25 feet
%
percent
ProbSurge25c
@@ -92,327 +116,9 @@
SFC
-
- staticCoriolis
- Coriolis parameter
- /s
- -99999.0
-
-
- Surge30Pct
- 80 hr Hurricane Storm Surge Percentile(30)
- feet
- feet
- SURGE30pct
- 0.0
- 25.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- Surge20Pct
- 80 hr Hurricane Storm Surge Percentile(20)
- feet
- feet
- SURGE20pct
- 0.0
- 25.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge16Ft
- 80 hr Prob of Hurricane Storm Surge > 16 feet
- %
- percent
- ProbSurge16c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- staticSpacing
- Grid spacing
- meters
- -99999.0
-
-
- PSurge11Ft
- 80 hr Prob of Hurricane Storm Surge > 11 feet
- %
- percent
- ProbSurge11c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge10Ft
- 80 hr Prob of Hurricane Storm Surge > 10 feet
- %
- percent
- ProbSurge10c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge15Ft
- 80 hr Prob of Hurricane Storm Surge > 15 feet
- %
- percent
- ProbSurge15c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge14Ft
- 80 hr Prob of Hurricane Storm Surge > 14 feet
- %
- percent
- ProbSurge14c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge2Ft
- 80 hr Prob of Hurricane Storm Surge > 2 feet
- %
- percent
- ProbSurge02c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- Surge70Pct
- 80 hr Hurricane Storm Surge Percentile(70)
- feet
- feet
- SURGE70pct
- 0.0
- 25.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge17Ft
- 80 hr Prob of Hurricane Storm Surge > 17 feet
- %
- percent
- ProbSurge17c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge6Ft
- 80 hr Prob of Hurricane Storm Surge > 6 feet
- %
- percent
- ProbSurge06c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge4Ft
- 80 hr Prob of Hurricane Storm Surge > 4 feet
- %
- percent
- ProbSurge04c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge8Ft
- 80 hr Prob of Hurricane Storm Surge > 8 feet
- %
- percent
- ProbSurge08c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge19Ft
- 80 hr Prob of Hurricane Storm Surge > 19 feet
- %
- percent
- ProbSurge19c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- staticTopo
- Topography
- meters
- -99999.0
-
-
- PSurge18Ft
- 80 hr Prob of Hurricane Storm Surge > 18 feet
- %
- percent
- ProbSurge18c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- SloshSurge
- slosh max surge
- feet
- feet
- SloshSurge
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- Surge50Pct
- 80 hr Hurricane Storm Surge Percentile(50)
- feet
- feet
- SURGE50pct
- 0.0
- 25.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge22Ft
- 80 hr Prob of Hurricane Storm Surge > 22 feet
- %
- percent
- ProbSurge22c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- Surge80Pct
- 80 hr Hurricane Storm Surge Percentile(80)
- feet
- feet
- SURGE80pct
- 0.0
- 25.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- PSurge20Ft
- 80 hr Prob of Hurricane Storm Surge > 20 feet
- %
- percent
- ProbSurge20c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
PSurge24Ft
- 80 hr Prob of Hurricane Storm Surge > 24 feet
+ Prob of Hurricane Storm Surge > 24 feet
%
percent
ProbSurge24c
@@ -425,9 +131,166 @@
SFC
+
+ PSurge23Ft
+ Prob of Hurricane Storm Surge > 23 feet
+ %
+ percent
+ ProbSurge23c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC
+
+ SFC
+
+
+
+ PSurge22Ft
+ Prob of Hurricane Storm Surge > 22 feet
+ %
+ percent
+ ProbSurge22c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC
+
+ SFC
+
+
+
+ PSurge21Ft
+ Prob of Hurricane Storm Surge > 21 feet
+ %
+ percent
+ ProbSurge21c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC
+
+ SFC
+
+
+
+ PSurge20Ft
+ Prob of Hurricane Storm Surge > 20 feet
+ %
+ percent
+ ProbSurge20c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge19Ft
+ Prob of Hurricane Storm Surge > 19 feet
+ %
+ percent
+ ProbSurge19c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge18Ft
+ Prob of Hurricane Storm Surge > 18 feet
+ %
+ percent
+ ProbSurge18c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge17Ft
+ Prob of Hurricane Storm Surge > 17 feet
+ %
+ percent
+ ProbSurge17c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge16Ft
+ Prob of Hurricane Storm Surge > 16 feet
+ %
+ percent
+ ProbSurge16c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge15Ft
+ Prob of Hurricane Storm Surge > 15 feet
+ %
+ percent
+ ProbSurge15c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge14Ft
+ Prob of Hurricane Storm Surge > 14 feet
+ %
+ percent
+ ProbSurge14c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
PSurge13Ft
- 80 hr Prob of Hurricane Storm Surge > 13 feet
+ Prob of Hurricane Storm Surge > 13 feet
%
percent
ProbSurge13c
@@ -435,14 +298,15 @@
100.0
-9999.0
0
- SFC
+ SFC 0 FHAG
+ FHAG0
SFC
PSurge12Ft
- 80 hr Prob of Hurricane Storm Surge > 12 feet
+ Prob of Hurricane Storm Surge > 12 feet
%
percent
ProbSurge12c
@@ -450,74 +314,47 @@
100.0
-9999.0
0
- SFC
+ SFC 0 FHAG
+ FHAG0
SFC
- PSurge5Ft
- 80 hr Prob of Hurricane Storm Surge > 5 feet
+ PSurge11Ft
+ Prob of Hurricane Storm Surge > 11 feet
%
percent
- ProbSurge05c
+ ProbSurge11c
0.0
100.0
-9999.0
0
- SFC
+ SFC 0 FHAG
+ FHAG0
SFC
- PSurge3Ft
- 80 hr Prob of Hurricane Storm Surge > 3 feet
+ PSurge10Ft
+ Prob of Hurricane Storm Surge > 10 feet
%
percent
- ProbSurge03c
+ ProbSurge10c
0.0
100.0
-9999.0
0
- SFC
-
- SFC
-
-
-
- PSurge7Ft
- 80 hr Prob of Hurricane Storm Surge > 7 feet
- %
- percent
- ProbSurge07c
- 0.0
- 100.0
- -9999.0
- 0
- SFC
-
- SFC
-
-
-
- Surge90Pct
- 80 hr Hurricane Storm Surge Percentile(90)
- feet
- feet
- SURGE90pct
- 0.0
- 25.0
- -9999.0
- 0
- SFC
+ SFC 0 FHAG
+ FHAG0
SFC
PSurge9Ft
- 80 hr Prob of Hurricane Storm Surge > 9 feet
+ Prob of Hurricane Storm Surge > 9 feet
%
percent
ProbSurge09c
@@ -525,24 +362,562 @@
100.0
-9999.0
0
- SFC
+ SFC 0 FHAG
+ FHAG0
SFC
- Surge10Pct
- 80 hr Hurricane Storm Surge Percentile(10)
- feet
- feet
- SURGE10pct
+ PSurge8Ft
+ Prob of Hurricane Storm Surge > 8 feet
+ %
+ percent
+ ProbSurge08c
0.0
- 25.0
+ 100.0
-9999.0
0
- SFC
+ SFC 0 FHAG
+ FHAG0
SFC
+
+ PSurge7Ft
+ Prob of Hurricane Storm Surge > 7 feet
+ %
+ percent
+ ProbSurge07c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge6Ft
+ Prob of Hurricane Storm Surge > 6 feet
+ %
+ percent
+ ProbSurge06c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge5Ft
+ Prob of Hurricane Storm Surge > 5 feet
+ %
+ percent
+ ProbSurge05c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge4Ft
+ Prob of Hurricane Storm Surge > 4 feet
+ %
+ percent
+ ProbSurge04c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge3Ft
+ Prob of Hurricane Storm Surge > 3 feet
+ %
+ percent
+ ProbSurge03c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge2Ft
+ Prob of Hurricane Storm Surge > 2 feet
+ %
+ percent
+ ProbSurge02c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ SFC 0 FHAG
+
+ FHAG0
+ SFC
+
+
+
+ PSurge1Ft
+ Prob of Hurricane Storm Surge > 1 feet
+ %
+ percent
+ ProbSurge01c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge0Ft
+ Prob of Hurricane Storm Surge > 0 feet
+ %
+ percent
+ ProbSurge00c
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+
+ Surge10Pctincr
+ 6 hr Hurricane Storm Surge Percentile(10)
+ m
+ meters
+ SURGE10pct_incr
+ -100.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ Surge20Pctincr
+ 6 hr Hurricane Storm Surge Percentile(20)
+ m
+ meters
+ SURGE20pct_incr
+ -100.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ Surge30Pctincr
+ 6 hr Hurricane Storm Surge Percentile(30)
+ m
+ meters
+ SURGE30pct_incr
+ -100.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ Surge40Pctincr
+ 6 hr Hurricane Storm Surge Percentile(40)
+ m
+ meters
+ SURGE40pct_incr
+ -100.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ Surge50Pctincr
+ 6 hr Hurricane Storm Surge Percentile(50)
+ m
+ meters
+ SURGE50pct_incr
+ -100.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge20Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 20 feet
+ %
+ percent
+ ProbSurge20c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge19Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 19 feet
+ %
+ percent
+ ProbSurge19c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge18Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 18 feet
+ %
+ percent
+ ProbSurge18c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge17Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 17 feet
+ %
+ percent
+ ProbSurge17c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge16Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 16 feet
+ %
+ percent
+ ProbSurge16c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge15Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 15 feet
+ %
+ percent
+ ProbSurge15c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge14Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 14 feet
+ %
+ percent
+ ProbSurge14c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge13Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 13 feet
+ %
+ percent
+ ProbSurge13c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge12Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 12 feet
+ %
+ percent
+ ProbSurge12c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge11Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 11 feet
+ %
+ percent
+ ProbSurge11c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge10Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 10 feet
+ %
+ percent
+ ProbSurge10c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge9Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 9 feet
+ %
+ percent
+ ProbSurge09c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge8Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 8 feet
+ %
+ percent
+ ProbSurge08c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge7Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 7 feet
+ %
+ percent
+ ProbSurge07c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge6Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 6 feet
+ %
+ percent
+ ProbSurge06c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge5Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 5 feet
+ %
+ percent
+ ProbSurge05c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge4Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 4 feet
+ %
+ percent
+ ProbSurge04c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge3Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 3 feet
+ %
+ percent
+ ProbSurge03c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge2Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 2 feet
+ %
+ percent
+ ProbSurge02c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge1Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 1 feet
+ %
+ percent
+ ProbSurge01c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+ PSurge0Ftincr
+ 6 hr Prob of Hurricane Storm Surge > 0 feet
+ %
+ percent
+ ProbSurge00c_incr
+ 0.0
+ 100.0
+ -9999.0
+ 0
+ 0 FHAG
+
+ FHAG0
+
+
+
+
+ staticTopo
+ Topography
+ meters
+ -99999.0
+
+
+ staticCoriolis
+ Coriolis parameter
+ /s
+ -99999.0
+
+
+ staticSpacing
+ Grid spacing
+ meters
+ -99999.0
+
diff --git a/edexOsgi/com.raytheon.edex.plugin.grib/GribDecoder.py b/edexOsgi/com.raytheon.edex.plugin.grib/GribDecoder.py
index d5a0190ae4..204ec8c060 100644
--- a/edexOsgi/com.raytheon.edex.plugin.grib/GribDecoder.py
+++ b/edexOsgi/com.raytheon.edex.plugin.grib/GribDecoder.py
@@ -578,7 +578,10 @@ class GribDecoder():
if levelName=='EATM':
levelOneValue=float(0)
levelTwoValue=float(Level.getInvalidLevelValue())
-
+
+ durationSecs = None
+ typeOfTimeInterval = None
+
# Special case handling for specific PDS Templates
if pdsTemplateNumber == 1 or pdsTemplateNumber == 11:
typeEnsemble = Integer(pdsTemplate[15]).intValue()
@@ -622,7 +625,6 @@ class GribDecoder():
elif pdsTemplateNumber == 5 or pdsTemplateNumber == 9:
- parameterUnit = "%"
probabilityNumber = pdsTemplate[15]
forecastProbabilities = pdsTemplate[16]
probabilityType = pdsTemplate[17]
@@ -636,31 +638,63 @@ class GribDecoder():
numTimeRanges = pdsTemplate[28]
numMissingValues = pdsTemplate[29]
statisticalProcess = pdsTemplate[30]
+ typeOfTimeInterval = pdsTemplate[31]
+ durationSecs = self._convertToSeconds(pdsTemplate[33], pdsTemplate[32])
+ scaledValue = None
if(probabilityType == 1 or probabilityType ==2):
- if(scaleFactorUL == 0):
- parameterAbbreviation = parameterAbbreviation+"_"+str(scaledValueUL)
- else:
- parameterAbbreviation = parameterAbbreviation+"_"+str(scaledValueUL)+"E"+str(scaleFactorUL)
- elif(probabilityType == 0):
- if(scaleFactorLL == 0):
- parameterAbbreviation = parameterAbbreviation+"_"+str(scaledValueLL)
- else:
- parameterAbbreviation = parameterAbbreviation+"_"+str(scaledValueLL)+"E"+str(scaleFactorLL)
+ scaledValue = self._convertScaledValue(scaledValueUL, scaleFactorUL)
+ parameterName = "Prob of " + parameterName + " > " + str(scaledValue) + parameterUnit
+ else:
+ scaledValue = self._convertScaledValue(scaledValueLL, scaleFactorLL)
+ parameterName = "Prob of " + parameterName + " < " + str(scaledValue) + parameterUnit
+ parameterAbbreviation = parameterAbbreviation + str(scaledValue) + parameterUnit
+
+ parameterUnit = "%"
elif pdsTemplateNumber == 8:
endTime = GregorianCalendar(pdsTemplate[15], pdsTemplate[16] - 1, pdsTemplate[17], pdsTemplate[18], pdsTemplate[19], pdsTemplate[20])
- numTimeRanges = pdsTemplate[21]
- numMissingValues = pdsTemplate[22]
- statisticalProcess = pdsTemplate[23]
+ #numTimeRanges = pdsTemplate[21]
+ #numMissingValues = pdsTemplate[22]
+ #statisticalProcess = pdsTemplate[23]
elif pdsTemplateNumber == 10:
+ parameterAbbreviation = parameterAbbreviation + str(pdsTemplate[15]) + "pct"
+ parameterName = str(pdsTemplate[15]) +"th percentile " + parameterName
+
endTime = GregorianCalendar(pdsTemplate[16], pdsTemplate[17] - 1, pdsTemplate[18], pdsTemplate[19], pdsTemplate[20], pdsTemplate[21])
numTimeRanges = pdsTemplate[22]
numMissingValues = pdsTemplate[23]
statisticalProcess = pdsTemplate[24]
+
+ typeOfTimeInterval = pdsTemplate[25]
+ durationSecs = self._convertToSeconds(pdsTemplate[27], pdsTemplate[26])
+
+
+ if durationSecs is not None:
+ # This only applies for templates 9 and 10 which are not
+ # commonly used templates. For all other data the duration is
+ # ignored and it is assumed that reftime, forecast time, and
+ # endtime will define the duration. For Template 9 and 10 this
+ # will cause forecast time to be ignored so duration is correct.
+
+ # The decoder assumes reftime + forecastTime equals
+ # endTime - duration, however for some models
+ # reftime + forecasttime instead equals endTime. This reassigns
+ # forecastTime as endTime - refTime - duration so that
+ # duration is correctly calculated.
+ refTime = GregorianCalendar(idSection[5], idSection[6] - 1, idSection[7], idSection[8], idSection[9], idSection[10])
+ refToEndSecs = (endTime.getTimeInMillis() - refTime.getTimeInMillis())/ 1000
+ forecastTime = refToEndSecs - durationSecs
+
+ if typeOfTimeInterval == 192 and centerID == 7 and subcenterID == 14:
+ # For TPC Surge data the type of time interval is significant and they have indicated that
+ # 192 means the data is cumulative. Since we don't ordinarily do table lookups on the
+ # type of time interval we must encode this information in the parameter abbreviation here.
+ parameterAbbreviation = parameterAbbreviation + "Cumul"
+ parameterName = parameterName + " - cumulative"
if(pdsTemplate[2] == 6 or pdsTemplate[2] == 7):
parameterAbbreviation = parameterAbbreviation+"erranl"
diff --git a/edexOsgi/com.raytheon.edex.plugin.grib/src/com/raytheon/edex/plugin/grib/decoderpostprocessors/TPCSurgeProbPostProcessor.java b/edexOsgi/com.raytheon.edex.plugin.grib/src/com/raytheon/edex/plugin/grib/decoderpostprocessors/TPCSurgeProbPostProcessor.java
deleted file mode 100644
index 36a16f9939..0000000000
--- a/edexOsgi/com.raytheon.edex.plugin.grib/src/com/raytheon/edex/plugin/grib/decoderpostprocessors/TPCSurgeProbPostProcessor.java
+++ /dev/null
@@ -1,127 +0,0 @@
-/**
- * This software was developed and / or modified by Raytheon Company,
- * pursuant to Contract DG133W-05-CQ-1067 with the US Government.
- *
- * U.S. EXPORT CONTROLLED TECHNICAL DATA
- * This software product contains export-restricted data whose
- * export/transfer/disclosure is restricted by U.S. law. Dissemination
- * to non-U.S. persons whether in the United States or abroad requires
- * an export license or other authorization.
- *
- * Contractor Name: Raytheon Company
- * Contractor Address: 6825 Pine Street, Suite 340
- * Mail Stop B8
- * Omaha, NE 68106
- * 402.291.0100
- *
- * See the AWIPS II Master Rights File ("Master Rights File.pdf") for
- * further licensing information.
- **/
-package com.raytheon.edex.plugin.grib.decoderpostprocessors;
-
-import java.util.HashMap;
-import java.util.Map;
-
-import com.raytheon.edex.plugin.grib.exception.GribException;
-import com.raytheon.uf.common.dataplugin.grid.GridRecord;
-import com.raytheon.uf.common.parameter.Parameter;
-
-/**
- * TODO Add Description
- *
- *
- *
- * SOFTWARE HISTORY
- *
- * Date Ticket# Engineer Description
- * ------------ ---------- ----------- --------------------------
- * Sep 7, 2011 bphillip Initial creation
- *
- *
- *
- * @author bphillip
- * @version 1.0
- */
-
-public class TPCSurgeProbPostProcessor implements IDecoderPostProcessor {
-
- private static final String PROB_NAME = "Probabilistic Storm Surge probability > %1 feet";
-
- private static final Map TPCSG_MAP = new HashMap();
-
- static {
- TPCSG_MAP.put("2", PROB_NAME.replace("%1", "2"));
- TPCSG_MAP.put("3", PROB_NAME.replace("%1", "3"));
- TPCSG_MAP.put("4", PROB_NAME.replace("%1", "4"));
- TPCSG_MAP.put("5", PROB_NAME.replace("%1", "5"));
- TPCSG_MAP.put("6", PROB_NAME.replace("%1", "6"));
- TPCSG_MAP.put("7", PROB_NAME.replace("%1", "7"));
- TPCSG_MAP.put("8", PROB_NAME.replace("%1", "8"));
- TPCSG_MAP.put("9", PROB_NAME.replace("%1", "9"));
- TPCSG_MAP.put("10", PROB_NAME.replace("%1", "10"));
- TPCSG_MAP.put("11", PROB_NAME.replace("%1", "11"));
- TPCSG_MAP.put("12", PROB_NAME.replace("%1", "12"));
- TPCSG_MAP.put("13", PROB_NAME.replace("%1", "13"));
- TPCSG_MAP.put("14", PROB_NAME.replace("%1", "14"));
- TPCSG_MAP.put("15", PROB_NAME.replace("%1", "15"));
- TPCSG_MAP.put("16", PROB_NAME.replace("%1", "16"));
- TPCSG_MAP.put("17", PROB_NAME.replace("%1", "17"));
- TPCSG_MAP.put("18", PROB_NAME.replace("%1", "18"));
- TPCSG_MAP.put("19", PROB_NAME.replace("%1", "19"));
- TPCSG_MAP.put("20", PROB_NAME.replace("%1", "20"));
- TPCSG_MAP.put("21", PROB_NAME.replace("%1", "21"));
- TPCSG_MAP.put("22", PROB_NAME.replace("%1", "22"));
- TPCSG_MAP.put("23", PROB_NAME.replace("%1", "23"));
- TPCSG_MAP.put("24", PROB_NAME.replace("%1", "24"));
- TPCSG_MAP.put("25", PROB_NAME.replace("%1", "25"));
- }
-
- /*
- * (non-Javadoc)
- *
- * @see
- * com.raytheon.edex.plugin.grib.decoderpostprocessors.IDecoderPostProcessor
- * #process(com.raytheon.uf.common.dataplugin.grib.GridRecord)
- */
- @Override
- public GridRecord[] process(GridRecord record) throws GribException {
- boolean modified = false;
- Parameter param = record.getParameter();
- if (param.getAbbreviation().startsWith("PSurge")) {
- String surge = param.getAbbreviation().toLowerCase()
- .replace("psurge", "").replace("ft", "");
- param = new Parameter(param.getAbbreviation(),
- TPCSG_MAP.get(surge), param.getUnitString());
- modified = true;
- } else if (param.getAbbreviation().equals("TPCSG_SLOSH")) {
- param = new Parameter(param.getAbbreviation(),
- "Real Time Slosh MEOW", param.getUnitString());
- modified = true;
- } else if (param.getAbbreviation().startsWith("TPCSG-")) {
- String abbr = param.getAbbreviation().substring(0, 8)
- .replace("-", "_");
- param = new Parameter(abbr, param.getName(), param.getUnitString());
- modified = true;
- } else if (param.getAbbreviation().endsWith("10Pct")) {
- String abbr = param.getAbbreviation().replace("10Pct", "");
- param = new Parameter(abbr, param.getName(), param.getUnitString());
- modified = true;
- }
- if (!modified) {
- return new GridRecord[] { record };
- }
-
- record.setParameter(param);
- record.getInfo().setId(null);
- record.setDataURI(null);
- try {
- record.constructDataURI();
- } catch (Exception e) {
- throw new GribException(
- "Error creating new dataURI for TPCSurgeProb data!", e);
- }
-
- record.setOverwriteAllowed(true);
- return new GridRecord[] { record };
- }
-}
diff --git a/edexOsgi/com.raytheon.edex.plugin.grib/utility/common_static/base/grid/master_grib2_lookup.txt b/edexOsgi/com.raytheon.edex.plugin.grib/utility/common_static/base/grid/master_grib2_lookup.txt
index 3563498d3d..df6ad9f16b 100644
--- a/edexOsgi/com.raytheon.edex.plugin.grib/utility/common_static/base/grid/master_grib2_lookup.txt
+++ b/edexOsgi/com.raytheon.edex.plugin.grib/utility/common_static/base/grid/master_grib2_lookup.txt
@@ -50,12 +50,12 @@ ThP_T170L42A-NCEP-MDL_1073x689_21600-0 ThP6hr
ThP_T170L42A-NCEP-MDL_1073x689_10800-0 ThP3hr
TP_254E3_T170L42A-NCEP-MDL_1649x1105_21600-0 POP6hr
TP_254E3_T170L42A-NCEP-MDL_1649x1105_43200-0 POP12hr
-WS_17491E3 Prob34
-WS_25722E3 Prob50
-WS_32924E3 Prob64
-PWS34_17491E3 PWS34
-PWS50_25722E3 PWS50
-PWS64_32924E3 PWS64
+WS17.491m/s Prob34
+WS25.722m/s Prob50
+WS32.924m/s Prob64
+PWS17.491m/s PWS34
+PWS25.722m/s PWS50
+PWS32.924m/s PWS64
MxT_ECMFMOD-1DEG-ECMF_10800-0 MxT3hr
MxT_ECMFMOD-1DEG-ECMF_21600-0 MxT6hr
MnT_ECMFMOD-1DEG-ECMF_10800-0 MnT3hr
@@ -74,72 +74,72 @@ TPmean_43200-0 TP12mean
TPsprd_43200-0 TP12sprd
TPmean_86400-0 TP24mean
TPsprd_86400-0 TP24sprd
-Vis_1609000E3 Visc1
-Vis_4827000E3 Visc2
-WS_12890E3 WSc1
-WS_17500E3 WSc2
-WS_25700E3 WSc3
-WS_25780E3 WSc4
-GH_152500E3 Cigc1
-GH_305000E3 Cigc2
-GH_914600E3 Cigc3
-T_273000E3 Tc1
-CAPE_500000E3 CAPEc1
-CAPE_1000000E3 CAPEc2
-CAPE_2000000E3 CAPEc3
-CAPE_3000000E3 CAPEc4
-CAPE_4000000E3 CAPEc5
-CFRZR_1000E3 CFRZRc1
-CICEP_1000E3 CICEPc1
-CRAIN_1000E3 CRAINc1
-CSNOW_1000E3 CSNOWc1
-PLI_0E3 PLIxc1
-PLI_-2000E3 PLIxc2
-PLI_-4000E3 PLIxc3
-PLI_-6000E3 PLIxc4
-PLI_-8000E3 PLIxc5
-TP_250E3_10800-0 tp3c1
-TP_1270E3_10800-0 tp3c2
-TP_2540E3_10800-0 tp3c3
-TP_6350E3_10800-0 tp3c4
-TP_12700E3_10800-0 tp3c5
-TP_25400E3_10800-0 tp3c6
-TP_38100E3_10800-0 tp3c7
-TP_50800E3_10800-0 tp3c8
-TP_250E3_21600-0 tp6c1
-TP_1270E3_21600-0 tp6c2
-TP_2540E3_21600-0 tp6c3
-TP_6350E3_21600-0 tp6c4
-TP_12700E3_21600-0 tp6c5
-TP_25400E3_21600-0 tp6c6
-TP_38100E3_21600-0 tp6c7
-TP_50800E3_21600-0 tp6c8
-TP_250E3_43200-0 tp12c1
-TP_1270E3_43200-0 tp12c2
-TP_2540E3_43200-0 tp12c3
-TP_6350E3_43200-0 tp12c4
-TP_12700E3_43200-0 tp12c5
-TP_25400E3_43200-0 tp12c6
-TP_38100E3_43200-0 tp12c7
-TP_50800E3_43200-0 tp12c8
-TP_250E3_86400-0 tp24c1
-TP_1270E3_86400-0 tp24c2
-TP_2540E3_86400-0 tp24c3
-TP_6350E3_86400-0 tp24c4
-TP_12700E3_86400-0 tp24c5
-TP_25400E3_86400-0 tp24c6
-TP_38100E3_86400-0 tp24c7
-TP_50800E3_86400-0 tp24c8
-SNOL_25400E3_43200-0 SNOL12c1
-SNOL_50800E3_43200-0 SNOL12c2
-SNOL_101600E3_43200-0 SNOL12c3
-SNOL_152400E3_43200-0 SNOL12c4
-SNOL_190500E3_43200-0 SNOL12c5
-SNOL_203200E3_43200-0 SNOL12c6
-SNOL_254000E3_43200-0 SNOL12c7
-SNOL_304800E3_43200-0 SNOL12c8
-SNOL_406400E3_43200-0 SNOL12c9
-SNOL_609600E3_43200-0 SNOL12c10
+Vis1609.0m Visc1
+Vis4827.0m Visc2
+WS12.89m/s WSc1
+WS17.5m/s WSc2
+WS25.7m/s WSc3
+WS25.78m/s WSc4
+GH152.5gpm Cigc1
+GH305.0gpm Cigc2
+GH914.6gpm Cigc3
+T273.0K Tc1
+CAPE500.0J/kg CAPEc1
+CAPE1000.0J/kg CAPEc2
+CAPE2000.0J/kg CAPEc3
+CAPE3000.0J/kg CAPEc4
+CAPE4000.0J/kg CAPEc5
+CFRZR1.0 CFRZRc1
+CICEP1.0 CICEPc1
+CRAIN1.0 CRAINc1
+CSNOW1.0 CSNOWc1
+PLI0.0K PLIxc1
+PLI-2.0K PLIxc2
+PLI-4.0K PLIxc3
+PLI-6.0K PLIxc4
+PLI-8.0K PLIxc5
+TP0.25mm_10800-0 tp3c1
+TP1.27mm_10800-0 tp3c2
+TP2.54mm_10800-0 tp3c3
+TP6.35mm_10800-0 tp3c4
+TP12.7mm_10800-0 tp3c5
+TP25.4mm_10800-0 tp3c6
+TP38.1mm_10800-0 tp3c7
+TP50.8mm_10800-0 tp3c8
+TP0.25mm_21600-0 tp6c1
+TP1.27mm_21600-0 tp6c2
+TP2.54mm_21600-0 tp6c3
+TP6.35mm_21600-0 tp6c4
+TP12.7mm_21600-0 tp6c5
+TP25.4mm_21600-0 tp6c6
+TP38.1mm_21600-0 tp6c7
+TP50.8mm_21600-0 tp6c8
+TP0.25mm_43200-0 tp12c1
+TP1.27mm_43200-0 tp12c2
+TP2.54mm_43200-0 tp12c3
+TP6.35mm_43200-0 tp12c4
+TP12.7mm_43200-0 tp12c5
+TP25.4mm_43200-0 tp12c6
+TP38.1mm_43200-0 tp12c7
+TP50.8mm_43200-0 tp12c8
+TP0.25mm_86400-0 tp24c1
+TP1.27mm_86400-0 tp24c2
+TP2.54mm_86400-0 tp24c3
+TP6.35mm_86400-0 tp24c4
+TP12.7mm_86400-0 tp24c5
+TP25.4mm_86400-0 tp24c6
+TP38.1mm_86400-0 tp24c7
+TP50.8mm_86400-0 tp24c8
+SNOL25.4mm_43200-0 SNOL12c1
+SNOL508.0mm_43200-0 SNOL12c2
+SNOL101.6mm_43200-0 SNOL12c3
+SNOL152.4mm_43200-0 SNOL12c4
+SNOL190.5mm_43200-0 SNOL12c5
+SNOL203.2mm_43200-0 SNOL12c6
+SNOL254.0mm_43200-0 SNOL12c7
+SNOL304.8mm_43200-0 SNOL12c8
+SNOL406.4mm_43200-0 SNOL12c9
+SNOL609.6mm_43200-0 SNOL12c10
T_66E2_CPCMANU-NCEP-CPC_1073x689_604800-0 PTAM
T_33E2_CPCMANU-NCEP-CPC_1073x689_604800-0 PTBM
TP_66E2_CPCMANU-NCEP-CPC_1073x689_604800-0 PPAM
@@ -174,7 +174,6 @@ PTOR_254E3 PTOR
MINRH_NMM-NCEP_10800-0 MINRH3hr
MINRH_NMM-NCEP_43200-0 MINRH12hr
TP_254E3 POP
-TPCSG_MODEL0-NCEP-MDL TPCSG_SLOSH
// Throw 1-hr and 2-hr precip on the floor for RUC13
CP_RUC2-NCEP_165x165_7200-0 PWS64
@@ -199,3 +198,86 @@ WINDPROB_254E3 WINDPROB
SIGWINDPROB_254E3 SIGWINDPROB
PRSVR_254E3 PRSVR
PRSIGSV_254E3 PRSIGSV
+
+#TPCSurgeProb
+# For the pct parameters the parameters coming out of the grib files are coded
+# as the height where there is XX probability that the surge is less than a
+# height but the desired interpretation is XX probability that the surge is
+# greater than a height
+Surge10pct_21600-0 Surge90pct6hr
+Surge20pct_21600-0 Surge80pct6hr
+Surge30pct_21600-0 Surge70pct6hr
+Surge40pct_21600-0 Surge60pct6hr
+Surge50pct_21600-0 Surge50pct6hr
+Surge60pct_21600-0 Surge40pct6hr
+Surge70pct_21600-0 Surge30pct6hr
+Surge80pct_21600-0 Surge20pct6hr
+Surge90pct_21600-0 Surge10pct6hr
+# For the m parameters convert the abbreviation from the grib decoder contains
+# a height in meters but it was intended and can be dispalyed nicely as a
+# height in feet.
+Surge0.0m_21600-0 PSurge0ft6hr
+Surge0.3m_21600-0 PSurge1ft6hr
+Surge0.61m_21600-0 PSurge2ft6hr
+Surge0.91m_21600-0 PSurge3ft6hr
+Surge1.22m_21600-0 PSurge4ft6hr
+Surge1.52m_21600-0 PSurge5ft6hr
+Surge1.83m_21600-0 PSurge6ft6hr
+Surge2.13m_21600-0 PSurge7ft6hr
+Surge2.44m_21600-0 PSurge8ft6hr
+Surge2.74m_21600-0 PSurge9ft6hr
+Surge3.05m_21600-0 PSurge10ft6hr
+Surge3.35m_21600-0 PSurge11ft6hr
+Surge3.66m_21600-0 PSurge12ft6hr
+Surge3.96m_21600-0 PSurge13ft6hr
+Surge4.27m_21600-0 PSurge14ft6hr
+Surge4.57m_21600-0 PSurge15ft6hr
+Surge4.88m_21600-0 PSurge16ft6hr
+Surge5.18m_21600-0 PSurge17ft6hr
+Surge5.49m_21600-0 PSurge18ft6hr
+Surge5.79m_21600-0 PSurge19ft6hr
+Surge6.1m_21600-0 PSurge20ft6hr
+Surge6.4m_21600-0 PSurge21ft6hr
+Surge6.71m_21600-0 PSurge22ft6hr
+Surge7.01m_21600-0 PSurge23ft6hr
+Surge7.32m_21600-0 PSurge24ft6hr
+Surge7.62m_21600-0 PSurge25ft6hr
+# For the Cumulative this mapping not only inverses the percentages and
+# converts the heights, it also prevents the decoder from appending a duration
+# which is necessary because the duration increases for each forecast time.
+Surge10pctCumul Surge90pctCumul
+Surge20pctCumul Surge80pctCumul
+Surge30pctCumul Surge70pctCumul
+Surge40pctCumul Surge60pctCumul
+Surge50pctCumul Surge50pctCumul
+Surge60pctCumul Surge40pctCumul
+Surge70pctCumul Surge30pctCumul
+Surge80pctCumul Surge20pctCumul
+Surge90pctCumul Surge10pctCumul
+Surge0.0mCumul PSurge0ftCumul
+Surge0.3mCumul PSurge1ftCumul
+Surge0.61mCumul PSurge2ftCumul
+Surge0.91mCumul PSurge3ftCumul
+Surge1.22mCumul PSurge4ftCumul
+Surge1.52mCumul PSurge5ftCumul
+Surge1.83mCumul PSurge6ftCumul
+Surge2.13mCumul PSurge7ftCumul
+Surge2.44mCumul PSurge8ftCumul
+Surge2.74mCumul PSurge9ftCumul
+Surge3.05mCumul PSurge10ftCumul
+Surge3.35mCumul PSurge11ftCumul
+Surge3.66mCumul PSurge12ftCumul
+Surge3.96mCumul PSurge13ftCumul
+Surge4.27mCumul PSurge14ftCumul
+Surge4.57mCumul PSurge15ftCumul
+Surge4.88mCumul PSurge16ftCumul
+Surge5.18mCumul PSurge17ftCumul
+Surge5.49mCumul PSurge18ftCumul
+Surge5.79mCumul PSurge19ftCumul
+Surge6.1mCumul PSurge20ftCumul
+Surge6.4mCumul PSurge21ftCumul
+Surge6.71mCumul PSurge22ftCumul
+Surge7.01mCumul PSurge23ftCumul
+Surge7.32mCumul PSurge24ftCumul
+Surge7.62mCumul PSurge25ftCumul
+
diff --git a/edexOsgi/com.raytheon.edex.plugin.grib/utility/common_static/base/grid/parameterNameAlias.txt b/edexOsgi/com.raytheon.edex.plugin.grib/utility/common_static/base/grid/parameterNameAlias.txt
index 030a319953..fc2768528d 100644
--- a/edexOsgi/com.raytheon.edex.plugin.grib/utility/common_static/base/grid/parameterNameAlias.txt
+++ b/edexOsgi/com.raytheon.edex.plugin.grib/utility/common_static/base/grid/parameterNameAlias.txt
@@ -130,4 +130,83 @@ SREF243::SNOL12c3::Prob 12-hr SNOW > 4 in
SREF243::SNOL12c2::Prob 12-hr SNOW > 2 in
SREF243::SNOL12c5::Prob 12-hr SNOW > 7.5 in
SREF243::SNOL12c4::Prob 12-hr SNOW > 6 in
-SREF243::SNOL12c1::Prob 12-hr SNOW > 1 in
\ No newline at end of file
+SREF243::SNOL12c1::Prob 12-hr SNOW > 1 in
+TPCWindProb::Prob34::Probability of Wind Speed > 34 knots
+TPCWindProb::Prob50::Probability of Wind Speed > 50 knots
+TPCWindProb::Prob64::Probability of Wind Speed > 64 knots
+TPCWindProb::PWS34::Incremental Prob WS 34 kts or greater
+TPCWindProb::PWS50::Incremental Prob WS 50 kts or greater
+TPCWindProb::PWS64::Incremental Prob WS 64 kts or greater
+// For the TPCSurgeProb parameters the names need to be converted from metric
+// and the percentages need to be inverted, for more information see the
+// comments in master_grib2_lookup.txt
+TPCSurgeProb::Surge10pct6hr::6 Hour Surge 10% Exceedance Ht
+TPCSurgeProb::Surge20pct6hr::6 Hour Surge 20% Exceedance Ht
+TPCSurgeProb::Surge30pct6hr::6 Hour Surge 30% Exceedance Ht
+TPCSurgeProb::Surge40pct6hr::6 Hour Surge 40% Exceedance Ht
+TPCSurgeProb::Surge50pct6hr::6 Hour Surge 50% Exceedance Ht
+TPCSurgeProb::Surge60pct6hr::6 Hour Surge 60% Exceedance Ht
+TPCSurgeProb::Surge70pct6hr::6 Hour Surge 70% Exceedance Ht
+TPCSurgeProb::Surge80pct6hr::6 Hour Surge 80% Exceedance Ht
+TPCSurgeProb::Surge90pct6hr::6 Hour Surge 90% Exceedance Ht
+TPCSurgeProb::PSurge0ft6hr::6 hour Prob of Surge > 0 ft
+TPCSurgeProb::PSurge1ft6hr::6 hour Prob of Surge > 1 ft
+TPCSurgeProb::PSurge2ft6hr::6 hour Prob of Surge > 2 ft
+TPCSurgeProb::PSurge3ft6hr::6 hour Prob of Surge > 3 ft
+TPCSurgeProb::PSurge4ft6hr::6 hour Prob of Surge > 4 ft
+TPCSurgeProb::PSurge5ft6hr::6 hour Prob of Surge > 5 ft
+TPCSurgeProb::PSurge6ft6hr::6 hour Prob of Surge > 6 ft
+TPCSurgeProb::PSurge7ft6hr::6 hour Prob of Surge > 7 ft
+TPCSurgeProb::PSurge8ft6hr::6 hour Prob of Surge > 8 ft
+TPCSurgeProb::PSurge9ft6hr::6 hour Prob of Surge > 9 ft
+TPCSurgeProb::PSurge10ft6hr::6 hour Prob of Surge > 10 ft
+TPCSurgeProb::PSurge11ft6hr::6 hour Prob of Surge > 11 ft
+TPCSurgeProb::PSurge12ft6hr::6 hour Prob of Surge > 12 ft
+TPCSurgeProb::PSurge13ft6hr::6 hour Prob of Surge > 13 ft
+TPCSurgeProb::PSurge14ft6hr::6 hour Prob of Surge > 14 ft
+TPCSurgeProb::PSurge15ft6hr::6 hour Prob of Surge > 15 ft
+TPCSurgeProb::PSurge16ft6hr::6 hour Prob of Surge > 16 ft
+TPCSurgeProb::PSurge17ft6hr::6 hour Prob of Surge > 17 ft
+TPCSurgeProb::PSurge18ft6hr::6 hour Prob of Surge > 18 ft
+TPCSurgeProb::PSurge19ft6hr::6 hour Prob of Surge > 19 ft
+TPCSurgeProb::PSurge20ft6hr::6 hour Prob of Surge > 20 ft
+TPCSurgeProb::PSurge21ft6hr::6 hour Prob of Surge > 21 ft
+TPCSurgeProb::PSurge22ft6hr::6 hour Prob of Surge > 22 ft
+TPCSurgeProb::PSurge23ft6hr::6 hour Prob of Surge > 23 ft
+TPCSurgeProb::PSurge24ft6hr::6 hour Prob of Surge > 24 ft
+TPCSurgeProb::PSurge25ft6hr::6 hour Prob of Surge > 25 ft
+TPCSurgeProb::Surge10pctCumul::Cumulative Surge 10% Exceedance Ht
+TPCSurgeProb::Surge20pctCumul::Cumulative Surge 20% Exceedance Ht
+TPCSurgeProb::Surge30pctCumul::Cumulative Surge 30% Exceedance Ht
+TPCSurgeProb::Surge40pctCumul::Cumulative Surge 40% Exceedance Ht
+TPCSurgeProb::Surge50pctCumul::Cumulative Surge 50% Exceedance Ht
+TPCSurgeProb::Surge60pctCumul::Cumulative Surge 60% Exceedance Ht
+TPCSurgeProb::Surge70pctCumul::Cumulative Surge 70% Exceedance Ht
+TPCSurgeProb::Surge80pctCumul::Cumulative Surge 80% Exceedance Ht
+TPCSurgeProb::Surge90pctCumul::Cumulative Surge 90% Exceedance Ht
+TPCSurgeProb::PSurge0ftCumul::Cumulative Prob of Surge > 0 ft
+TPCSurgeProb::PSurge1ftCumul::Cumulative Prob of Surge > 1 ft
+TPCSurgeProb::PSurge2ftCumul::Cumulative Prob of Surge > 2 ft
+TPCSurgeProb::PSurge3ftCumul::Cumulative Prob of Surge > 3 ft
+TPCSurgeProb::PSurge4ftCumul::Cumulative Prob of Surge > 4 ft
+TPCSurgeProb::PSurge5ftCumul::Cumulative Prob of Surge > 5 ft
+TPCSurgeProb::PSurge6ftCumul::Cumulative Prob of Surge > 6 ft
+TPCSurgeProb::PSurge7ftCumul::Cumulative Prob of Surge > 7 ft
+TPCSurgeProb::PSurge8ftCumul::Cumulative Prob of Surge > 8 ft
+TPCSurgeProb::PSurge9ftCumul::Cumulative Prob of Surge > 9 ft
+TPCSurgeProb::PSurge10ftCumul::Cumulative Prob of Surge > 10 ft
+TPCSurgeProb::PSurge11ftCumul::Cumulative Prob of Surge > 11 ft
+TPCSurgeProb::PSurge12ftCumul::Cumulative Prob of Surge > 12 ft
+TPCSurgeProb::PSurge13ftCumul::Cumulative Prob of Surge > 13 ft
+TPCSurgeProb::PSurge14ftCumul::Cumulative Prob of Surge > 14 ft
+TPCSurgeProb::PSurge15ftCumul::Cumulative Prob of Surge > 15 ft
+TPCSurgeProb::PSurge16ftCumul::Cumulative Prob of Surge > 16 ft
+TPCSurgeProb::PSurge17ftCumul::Cumulative Prob of Surge > 17 ft
+TPCSurgeProb::PSurge18ftCumul::Cumulative Prob of Surge > 18 ft
+TPCSurgeProb::PSurge19ftCumul::Cumulative Prob of Surge > 19 ft
+TPCSurgeProb::PSurge20ftCumul::Cumulative Prob of Surge > 20 ft
+TPCSurgeProb::PSurge21ftCumul::Cumulative Prob of Surge > 21 ft
+TPCSurgeProb::PSurge22ftCumul::Cumulative Prob of Surge > 22 ft
+TPCSurgeProb::PSurge23ftCumul::Cumulative Prob of Surge > 23 ft
+TPCSurgeProb::PSurge24ftCumul::Cumulative Prob of Surge > 24 ft
+TPCSurgeProb::PSurge25ftCumul::Cumulative Prob of Surge > 25 ft
\ No newline at end of file
diff --git a/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/dataFieldTable.txt b/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/dataFieldTable.txt
index 41c9dd2458..355638dcb3 100644
--- a/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/dataFieldTable.txt
+++ b/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/dataFieldTable.txt
@@ -111,9 +111,6 @@ diam | || | Feature Diameter
g2gsh | || | Gate to Gate Shear
wDiv | || | Divergence
ICEG | iceg || | Ice growth rate
-Prob34 | prob34 || | Probability of Wind Speed > 34 knots
-Prob50 | prob50 || | Probability of Wind Speed > 50 knots
-Prob64 | prob64 || | Probability of Wind Speed > 64 knots
POP12hr | pop12hr || | Probability of 12hr precip
POP6hr | pop6hr || | Probability of 6hr precip
POP3hr | pop3hr || | Probability of 3hr precip
@@ -265,9 +262,6 @@ TP_ECMWF |tp_ecmwf || | ECMWF Total Precipitation
TP_ECMWF12hr | || | ECMWF 12-hr Total Precipitation
TP120hr |tp120hr || | 120-hr Total Precipitation
PPFFG | ppffg || | Probability of excessive rain
-PWS34 | pws34 || | Incremental Prob WS 34 kts or greater
-PWS50 | pws50 || | Incremental Prob WS 50 kts or greater
-PWS64 | pws64 || | Incremental Prob WS 64 kts or greater
SHerranl | sherranl || | RTMA Alaska specific humidity error analysis
Perranl | perranl || | RTMA Alaska pressure error analysis
TiltAng | || | Tilt angle of a radar PPI
@@ -276,16 +270,6 @@ ZDR | || | Radar differential reflectivity
KDP | || | Radar specific differential phase
COCO | || | Radar correlation coefficient
HC | || | Radar Hydrometeor Class
-TPCSG | Surge10Pct || | storm surge at 10 % Exceedance
-TPCSG_305E2 | PSurge10Ft || | storm surge probabilities > 10 feet
-TPCSG_274E2 | PSurge9Ft || | storm surge probabilities > 9 feet
-TPCSG_244E2 | PSurge8Ft || | storm surge probabilities > 8 feet
-TPCSG_213E2 | PSurge7Ft || | storm surge probabilities > 7 feet
-TPCSG_183E2 | PSurge6Ft || | storm surge probabilities > 6 feet
-TPCSG_152E2 | PSurge5Ft || | storm surge probabilities > 5 feet
-TPCSG_122E2 | PSurge4Ft || | storm surge probabilities > 4 feet
-TPCSG_91E2 | PSurge3Ft || | storm surge probabilities > 3 feet
-TPCSG_61E2 | PSurge2Ft || | storm surge probabilities > 2 feet
SIPD | sld || |Supercooled large droplet icing potential
TURB | turb || |Turbulence hazard forecast index
ICNG | icng || |Total icing potential diagnostic
@@ -310,29 +294,5 @@ snowd6hr | snowd6hr || | 6-hr Snow depth
PTOR | ptor || | Tornado Probability
MINRH3hr | minRH3hr || | 3-hr Minimum Relative Humidity
MINRH12hr| minRH12hr|| | 12-hr Minimum Relative Humidity
-TPCSG_SLOSH | SloshSurge || | Real Time Slosh MEOW
-TPCSG_20 | Surge20Pct || | storm surge at 20% Exceedance
-TPCSG_30 | Surge30Pct || | storm surge at 30% Exceedance
-TPCSG_40 | Surge40Pct || | storm surge at 40% Exceedance
-TPCSG_50 | Surge50Pct || | storm surge at 50% Exceedance
-TPCSG_60 | Surge60Pct || | storm surge at 60% Exceedance
-TPCSG_70 | Surge70Pct || | storm surge at 70% Exceedance
-TPCSG_80 | Surge80Pct || | storm surge at 80% Exceedance
-TPCSG_90 | Surge90Pct || | storm surge at 90% Exceedance
-TPCSG_335E2 | PSurge11Ft || | storm surge probabilities > 11 feet
-TPCSG_366E2 | PSurge12Ft || | storm surge probabilities > 12 feet
-TPCSG_396E2 | PSurge13Ft || | storm surge probabilities > 13 feet
-TPCSG_427E2 | PSurge14Ft || | storm surge probabilities > 14 feet
-TPCSG_457E2 | PSurge15Ft || | storm surge probabilities > 15 feet
-TPCSG_488E2 | PSurge16Ft || | storm surge probabilities > 16 feet
-TPCSG_518E2 | PSurge17Ft || | storm surge probabilities > 17 feet
-TPCSG_549E2 | PSurge18Ft || | storm surge probabilities > 18 feet
-TPCSG_579E2 | PSurge19Ft || | storm surge probabilities > 19 feet
-TPCSG_610E2 | PSurge20Ft || | storm surge probabilities > 20 feet
-TPCSG_640E2 | PSurge21Ft || | storm surge probabilities > 21 feet
-TPCSG_671E2 | PSurge22Ft || | storm surge probabilities > 22 feet
-TPCSG_701E2 | PSurge23Ft || | storm surge probabilities > 23 feet
-TPCSG_732E2 | PSurge24Ft || | storm surge probabilities > 24 feet
-TPCSG_762E2 | PSurge25Ft || | storm surge probabilities > 25 feet
CP2hr | cp2hr || | 2-hour Convective Precipitation
LgSP2hr | lgsp2hr || | 2-hour Large Scale Precipitation
diff --git a/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/largeGribPatterns.xml b/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/largeGribPatterns.xml
index 4bf2c4baf5..ba17962d4a 100644
--- a/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/largeGribPatterns.xml
+++ b/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/largeGribPatterns.xml
@@ -21,5 +21,10 @@
^al*
^tpcprblty*
+
^LGX[TP]*
+
+ ^L[L-X]X[QP][1-5]0
+
+ ^L[HG]X[A-M][0-2][0-9]
\ No newline at end of file
diff --git a/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/-1/-1/4.2.0.2.table b/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/-1/-1/4.2.0.2.table
index 51700d4667..be2242157b 100644
--- a/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/-1/-1/4.2.0.2.table
+++ b/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/-1/-1/4.2.0.2.table
@@ -32,8 +32,4 @@
30:30:Frictional velocity:m/s:FRICV
# 31-191 Reserved
# 192-254 Reserved for local use
-# AWIPS override of the PWS parameters
-198:198:Incremental Prob WS 34 kts or greater:%:PWS34
-199:199:Incremental Prob WS 50 kts or greater:%:PWS50
-200:200:Incremental Prob WS 50 kts or greater:%:PWS64
255:255:Missing
diff --git a/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/7/10/4.2.0.2.table b/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/7/10/4.2.0.2.table
index 87c17ab495..d62c8e69c8 100644
--- a/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/7/10/4.2.0.2.table
+++ b/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/7/10/4.2.0.2.table
@@ -6,9 +6,9 @@
195:195:V-Component Storm Motion:m/s:VSTM
196:196:Drag Coefficient::CD
197:197:Frictional Velocity:m/s:FRICV
-198:198:Incremental Prob WS 34 kts or greater:%:PWS34
-199:199:Incremental Prob WS 50 kts or greater:%:PWS50
-200:200:Incremental Prob WS 64 kts or greater:%:PWS64
+198:198:Wind speed:m/s:PWS
+199:199:Wind speed:m/s:PWS
+200:200:Wind speed:m/s:PWS
201:201:Longitude of V Wind Component of Velocity:degrees:LOVV
202:202:Latitude of Presure Point:degrees:LAPP
203:203:Longitude of Presure Point:degrees:LOPP
diff --git a/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/7/14/4.2.10.3.table b/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/7/14/4.2.10.3.table
index 34dc83c0b9..d743ed8c8c 100644
--- a/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/7/14/4.2.10.3.table
+++ b/edexOsgi/com.raytheon.edex.plugin.grib/utility/edex_static/base/grib/tables/7/14/4.2.10.3.table
@@ -1,6 +1,6 @@
# Product Discipline 10: Oceanographic products, Parameter Category 3: Surface Properties
#192-254 Reserved for local use
-192:192:Probabilistic Storm Surge height w/10% chance of being exceeded:m:TPCSG
+192:192:Surge Height:m:Surge
193:193:Extra Tropical Storm Surge:m:ETSRG
194:194:Ocean Surface Elevation Relative to Geoid:m:ELEV
195:195:Sea Surface Height Relative to Geoid:m:SSHG
@@ -11,13 +11,13 @@
200:200:Surface Salinity Trend:psu per day:SSST
201:201:Kinetic Energy:J/kg:KENG
202:202:Salt Flux:mm*s:SLTFL
-242:242:Probabilistic Storm Surge height w/20% chance of being exceeded:m:TPCSG_20
-243:243:Probabilistic Storm Surge height w/30% chance of being exceeded:m:TPCSG_30
-244:244:Probabilistic Storm Surge height w/40% chance of being exceeded:m:TPCSG_40
-245:245:Probabilistic Storm Surge height w/50% chance of being exceeded:m:TPCSG_50
-246:246:Probabilistic Storm Surge height w/60% chance of being exceeded:m:TPCSG_60
-247:247:Probabilistic Storm Surge height w/70% chance of being exceeded:m:TPCSG_70
-248:248:Probabilistic Storm Surge height w/80% chance of being exceeded:m:TPCSG_80
-249:249:Probabilistic Storm Surge height w/90% chance of being exceeded:m:TPCSG_90
+242:242:Surge Height:m:Surge
+243:243:Surge Height:m:Surge
+244:244:Surge Height:m:Surge
+245:245:Surge Height:m:Surge
+246:246:Surge Height:m:Surge
+247:247:Surge Height:m:Surge
+248:248:Surge Height:m:Surge
+249:249:Surge Height:m:Surge
250:250:Extra Tropical Storm Surge Combined Surge and Tide:m:ETCWL
255:255:Missing
diff --git a/rpms/awips2.core/Installer.ldm/component.spec b/rpms/awips2.core/Installer.ldm/component.spec
index 8830cf5b20..b4c6542c77 100644
--- a/rpms/awips2.core/Installer.ldm/component.spec
+++ b/rpms/awips2.core/Installer.ldm/component.spec
@@ -9,7 +9,7 @@
Name: awips2-ldm
Summary: AWIPS II LDM Distribution
Version: %{_ldm_version}
-Release: 9
+Release: 10
Group: AWIPSII
BuildRoot: /tmp
BuildArch: noarch
diff --git a/rpms/awips2.core/Installer.ldm/patch/etc/pqact.conf.template b/rpms/awips2.core/Installer.ldm/patch/etc/pqact.conf.template
index fa081abfb7..91c8cc0480 100644
--- a/rpms/awips2.core/Installer.ldm/patch/etc/pqact.conf.template
+++ b/rpms/awips2.core/Installer.ldm/patch/etc/pqact.conf.template
@@ -319,6 +319,14 @@ ANY ^(LGXT[0-2][0-9]) KNHC (..)(..)(..)
ANY ^(LGXP[0-9][0-9]) KNHC (..)(..)(..)
FILE -overwrite -log -close -edex /data_store/grib2/(\2:yyyy)(\2:mm)\2/\3/TPC/\3\4Z_SURGE-\1_KNHC_\2\3\4_(seq).grib2.%Y%m%d%H
+# TPCSurge PHISH heights
+#ANY ^(L[l-X]X[QP][1-5]0) KNHC (..)(..)(..)
+# FILE -overwrite -log -close -edex /data_store/grib2/(\2:yyyy)(\2:mm)\2/\3/TPC/\3\4Z_SURGE-\1_KNHC_\2\3\4_(seq).grib2.%Y%m%d%H
+
+# TPCSurge PHISH probabilities
+#ANY ^(L[H-G]X[A-M][0-2][0-9]) KNHC (..)(..)(..)
+# FILE -overwrite -log -close -edex /data_store/grib2/(\2:yyyy)(\2:mm)\2/\3/TPC/\3\4Z_SURGE-\1_KNHC_\2\3\4_(seq).grib2.%Y%m%d%H
+
# AWIPS1: GRID ^LDIZ11.*KWNS /Grid/SBN/rawGrib2
# LDIZ11 KWNS 180039 !grib2/ncep/0/#202/FHRS//LVL
diff --git a/rpms/build/x86_64/build.sh b/rpms/build/x86_64/build.sh
index e9fd84442e..7e28ebddc1 100644
--- a/rpms/build/x86_64/build.sh
+++ b/rpms/build/x86_64/build.sh
@@ -409,10 +409,10 @@ fi
if [ "${1}" = "-viz" ]; then
buildRPM "awips2"
- buildRPM "awips2-common-base"
+ #buildRPM "awips2-common-base"
#buildRPM "awips2-python-numpy"
#buildRPM "awips2-ant"
- buildRPM "awips2-python-dynamicserialize"
+ #buildRPM "awips2-python-dynamicserialize"
#buildRPM "awips2-python"
#buildRPM "awips2-adapt-native"
#unpackHttpdPypies
@@ -422,8 +422,8 @@ if [ "${1}" = "-viz" ]; then
#buildRPM "awips2-httpd-pypies"
#buildRPM "awips2-hydroapps-shared"
#buildRPM "awips2-rcm"
- buildRPM "awips2-gfesuite-client"
- buildRPM "awips2-gfesuite-server"
+ #buildRPM "awips2-gfesuite-client"
+ #buildRPM "awips2-gfesuite-server"
#buildRPM "awips2-tools"
#buildRPM "awips2-cli"
buildCAVE
@@ -454,10 +454,14 @@ if [ "${1}" = "-custom" ]; then
#fi
#buildRPM "awips2-adapt-native"
#buildRPM "awips2-hydroapps-shared"
+ buildRPM "awips2-common-base"
+ buildRPM "awips2-gfesuite-client"
+ buildRPM "awips2-gfesuite-server"
+ buildRPM "awips2-python-dynamicserialize"
#buildRPM "awips2-alertviz"
#buildRPM "awips2-python"
#buildRPM "awips2-alertviz"
- buildRPM "awips2-ant"
+ #buildRPM "awips2-ant"
#buildRPM "awips2-eclipse"
#buildRPM "awips2-python"
diff --git a/cave/com.raytheon.viz.grid/src/com/raytheon/viz/grid/rsc/general/D2DGridResource.java b/cave/com.raytheon.viz.grid/src/com/raytheon/viz/grid/rsc/general/D2DGridResource.java
index 53d6333731..1cb4744e46 100644
--- a/cave/com.raytheon.viz.grid/src/com/raytheon/viz/grid/rsc/general/D2DGridResource.java
+++ b/cave/com.raytheon.viz.grid/src/com/raytheon/viz/grid/rsc/general/D2DGridResource.java
@@ -73,16 +73,19 @@ import com.vividsolutions.jts.geom.Coordinate;
*
* SOFTWARE HISTORY
*
* Date Ticket# Engineer Description
* ------------ ---------- ----------- --------------------------
* Mar 09, 2011 bsteffen Initial creation
* Feb 25, 2013 1659 bsteffen Add PDOs to D2DGridResource in
* constructor to avoid duplicate data
* requests.
* Jul 15, 2013 2107 bsteffen Fix sampling of grid vector arrows.
* Aug 27, 2013 2287 randerso Removed 180 degree adjustment required by error
* in Maputil.rotation
* Sep 24, 2013 DR 15972 D. Friedman Make reprojection of grids configurable.
*
*
*
@@ -252,6 +255,10 @@ public class D2DGridResource extends GridResource implements
if (stylePreferences != null) {
legendParams.unit = stylePreferences.getDisplayUnitLabel();
+ if (stylePreferences.getDisplayFlags() != null) {
+ legendParams.isPlaneLabelDisplayed = !stylePreferences
+ .getDisplayFlags().hasFlag("NoPlane");
+ }
}
if (legendParams.unit == null || legendParams.unit.isEmpty()) {
@@ -73,16 +73,19 @@ import com.vividsolutions.jts.geom.Coordinate;
* SOFTWARE HISTORY
*
- * Date Ticket# Engineer Description
- * ------------ ---------- ----------- --------------------------
- * Mar 09, 2011 bsteffen Initial creation
- * Feb 25, 2013 1659 bsteffen Add PDOs to D2DGridResource in
- * constructor to avoid duplicate data
- * requests.
- * Jul 15, 2013 2107 bsteffen Fix sampling of grid vector arrows.
- * Aug 27, 2013 2287 randerso Removed 180 degree adjustment required by error
- * in Maputil.rotation
- * Sep 24, 2013 DR 15972 D. Friedman Make reprojection of grids configurable.
+ * Date Ticket# Engineer Description
+ * ------------- -------- ----------- --------------------------
+ * Mar 09, 2011 bsteffen Initial creation
+ * Feb 25, 2013 1659 bsteffen Add PDOs to D2DGridResource in
+ * constructor to avoid duplicate data
+ * requests.
+ * Jul 15, 2013 2107 bsteffen Fix sampling of grid vector arrows.
+ * Aug 27, 2013 2287 randerso Removed 180 degree adjustment required by
+ * error in Maputil.rotation
+ * Sep 24, 2013 15972 D. Friedman Make reprojection of grids configurable.
+ * Mar 27, 2014 2945 bsteffen Enable omitting the plane from the legend
+ * based off style rules.
+ *
*
*